#include <STC32G.H>
#include "../COMM/stc32_stc8_usb.h"
#include "DS18B20.h"

void sys_init();

//USB调试及复位所需定义
char *USER_DEVICEDESC = NULL;
char *USER_PRODUCTDESC = NULL;
char *USER_STCISPCMD = "@STCISP#";


void main()
{
	float temp;
	sys_init();
	
	IRC48MCR = 0x80;				// 使能内部48M的USB专用IRC
	while(!(IRC48MCR & 0x01));
	USBCLK = 0x00;					// 设置USB时钟源为内部48M的USB专用IRC
	USBCON = 0x90;					// 使能USB功能
	
	usb_init();						// 调用USB CDC初始化库函数
	EA = 1;
	EUSB = 1;						// 使能USB中断
	
	while(DeviceState != DEVSTATE_CONFIGURED);	// 等待USB配置完成
	
	temp = DS18B20_ReadTemp();
	
	while(1)
	{
		if (bUsbOutReady)							// 当硬件接收完成上位机通过串口助手发送数据后会自动将
        {											// bUsbOutReady 置1
            USB_SendData(UsbOutBuffer, OutNumber);	// 接收的数据字节数保存在OutNumber变量中
            usb_OUT_done();							// 接收的数据保存在UsbOutBuffer缓存区
			printf("temp is %.3f", temp);
			printf("temp is %d", (int)temp);
		}											// 使用USB_SendData库函数可向上位机发送数据
													// 调用usb_OUT_done 准备接收下一笔数据
		
	}
}

void sys_init()
{
    WTST = 0;  //设置程序指令延时参数，赋值为0可将CPU执行指令的速度设置为最快
    EAXFR = 1; //扩展寄存器(XFR)访问使能
    CKCON = 0; //提高访问XRAM速度

    P0M1 = 0x30;   P0M0 = 0x30;   //设置P0.4、P0.5为漏极开路(实验箱加了上拉电阻到3.3V)
    P1M1 = 0x32;   P1M0 = 0x32;   //设置P1.1、P1.4、P1.5为漏极开路(实验箱加了上拉电阻到3.3V), P1.1在PWM当DAC电路通过电阻串联到P2.3
    P2M1 = 0x3c;   P2M0 = 0x3c;   //设置P2.2~P2.5为漏极开路(实验箱加了上拉电阻到3.3V)，设置开漏模式需要断开PWM当DAC电路中的R2电阻
    P3M1 = 0x53;   P3M0 = 0x50;   //设置P3.4、P3.6为漏极开路(实验箱加了上拉电阻到3.3V)
	// P30/P31和USB的D-/D+共用PIN脚 需要将P30 P31设置为高阻输入模式
    P4M1 = 0x3c;   P4M0 = 0x3c;   //设置P4.2~P4.5为漏极开路(实验箱加了上拉电阻到3.3V)
    P5M1 = 0x0c;   P5M0 = 0x0c;   //设置P5.2、P5.3为漏极开路(实验箱加了上拉电阻到3.3V)
    P6M1 = 0xff;   P6M0 = 0xff;   //设置为漏极开路(实验箱加了上拉电阻到3.3V)
    P7M1 = 0x00;   P7M0 = 0x00;   //设置为准双向口
}